==> xwiki-platform-chart-macro-4.1.4-sources.jar: org/xwiki/rendering/macro/chart/ChartMacroParameters.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.macro.chart;

import java.util.HashMap;
import java.util.Map;

import org.xwiki.chart.ChartGenerator;
import org.xwiki.properties.annotation.PropertyDescription;
import org.xwiki.properties.annotation.PropertyMandatory;

/**
 * Parameters for chart macro.
 * 
 * @version $Id: 2a2a1f9711048edbe3d4921de162d0a19148a900 $
 * @since 2.0M1
 */
public class ChartMacroParameters
{
    /**
     * @see ChartMacroParameters#getTitle()
     */
    private String title;

    /**
     * @see ChartMacroParameters#getHeight()
     */
    private int height = 300;

    /**
     * @see ChartMacroParameters#getWidth()
     */
    private int width = 400;

    /**
     * @see ChartMacroParameters#getType()
     */
    private String type;

    /**
     * @see ChartMacroParameters#getSource()
     */
    private String source = "xdom";

    /**
     * @see ChartMacroParameters#getParams()
     */
    private String params;

    /**
     * @return The title of the chart.
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * @param title - refer to {@link #getTitle()}.
     */
    @PropertyDescription("The title of the chart (appears on top of the chart image)")
    public void setTitle(String title)
    {
        this.title = title;
    }

    /**
     * @return The width of the chart.
     */
    public int getWidth()
    {
        return width;
    }

    /**
     * @param width - refer to {@link #getWidth()}.
     */
    @PropertyDescription("The width of the generated chart image")
    public void setWidth(int width)
    {
        this.width = width;
    }

    /**
     * @return The height of the chart.
     */
    public int getHeight()
    {
        return height;
    }

    /**
     * @param height - refer to {@link #getHeight()}.
     */
    @PropertyDescription("The height of the generated chart image")
    public void setHeight(int height)
    {
        this.height = height;
    }

    /**
     * @return the type of the chart.
     */
    public String getType()
    {
        return type;
    }

    /**
     * @param chartType - refer to {@link #getType()}.
     */
    @PropertyMandatory
    @PropertyDescription("The type of the chart (Ex. pie, line, area or bar)")
    public void setType(String chartType)
    {
        this.type = chartType;
    }

    /**
     * @return a string describing the data source
     */
    public String getSource()
    {
        return source;
    }

    /**
     * @param source - refer to {@link #getSource()

     */
    @PropertyDescription("The string describing the type of input data source (Ex. xdom or inline)")
    public void setSource(String source)
    {
        this.source = source;
    }

    /**
     * @return Additional parameters for the data source.
     */
    public String getParams()
    {
        return params;
    }

    /**
     * @param params Additional parameters for the data source.
     */
    @PropertyDescription("Additional parameters for the data source")
    public void setParams(String params)
    {
        this.params = params;
    }

    /**
     * @return a Map containing all the parameters.
     */
    public Map<String, String> getParametersMap()
    {
        Map<String, String> map = new HashMap<String, String>();
        map.put(ChartGenerator.TITLE_PARAM, getTitle());
        map.put(ChartGenerator.WIDTH_PARAM, String.valueOf(getWidth()));
        map.put(ChartGenerator.HEIGHT_PARAM, String.valueOf(getHeight()));
        map.put(ChartGenerator.TYPE_PARAM, getType());
        map.put(ChartDataSource.SOURCE, getSource());
        map.put(ChartDataSource.PARAMS, getParams());
        return map;
    }
}

==> xwiki-platform-chart-macro-7.4.5-sources.jar: org/xwiki/rendering/macro/chart/ChartMacroParameters.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.macro.chart;

import org.xwiki.properties.annotation.PropertyDescription;
import org.xwiki.properties.annotation.PropertyMandatory;

/**
 * Parameters for chart macro.
 *
 * @version $Id: 8c79d703afe9cdbb1bb1f0e1cf7e5b6e7a906cf2 $
 * @since 2.0M1
 */
public class ChartMacroParameters
{
    /**
     * @see ChartMacroParameters#getTitle()
     */
    private String title;

    /**
     * @see ChartMacroParameters#getHeight()
     */
    private int height = 300;

    /**
     * @see ChartMacroParameters#getWidth()
     */
    private int width = 400;

    /**
     * @see ChartMacroParameters#getType()
     */
    private String type;

    /**
     * @see ChartMacroParameters#getSource()
     */
    private String source;

    /**
     * @see ChartMacroParameters#getParams()
     */
    private String params;

    /**
     * @return The title of the chart.
     */
    public String getTitle()
    {
        return title;
    }

    /**
     * @param title - refer to {@link #getTitle()}.
     */
    @PropertyDescription("The title of the chart (appears on top of the chart image)")
    public void setTitle(String title)
    {
        this.title = title;
    }

    /**
     * @return The width of the chart.
     */
    public int getWidth()
    {
        return width;
    }

    /**
     * @param width - refer to {@link #getWidth()}.
     */
    @PropertyDescription("The width of the generated chart image")
    public void setWidth(int width)
    {
        this.width = width;
    }

    /**
     * @return The height of the chart.
     */
    public int getHeight()
    {
        return height;
    }

    /**
     * @param height - refer to {@link #getHeight()}.
     */
    @PropertyDescription("The height of the generated chart image")
    public void setHeight(int height)
    {
        this.height = height;
    }

    /**
     * @return the type of the chart.
     */
    public String getType()
    {
        return type;
    }

    /**
     * @param chartType - refer to {@link #getType()}.
     */
    @PropertyMandatory
    @PropertyDescription("The type of the chart (Ex. pie, line, area or bar)")
    public void setType(String chartType)
    {
        this.type = chartType;
    }

    /**
     * @return a string describing the data source
     */
    public String getSource()
    {
        return source;
    }

    /**
     * @param source - refer to {@link #getSource()
     */
    @PropertyDescription("The string describing the type of input data source (Ex. xdom or inline)")
    public void setSource(String source)
    {
        this.source = source;
    }

    /**
     * @return Additional parameters for the data source.
     */
    public String getParams()
    {
        return params;
    }

    /**
     * @param params Additional parameters for the data source.
     */
    @PropertyDescription("Additional parameters for the data source")
    public void setParams(String params)
    {
        this.params = params;
    }
}
